## [v0.1.2](https://pypi.org/project/amsdal_ml/0.1.2/) - 2025-10-08

### Changed object_id in EmbeddingModel

- Fix for UserWarning: Field name "object_id" in "EmbeddingModel" shadows an attribute in parent "Model"